# PyPatches

[![Documentation Status](https://readthedocs.org/projects/binary-patches/badge/?version=main)](https://binary-patches.readthedocs.io/en/main/?badge=main)

## Documentation

Documentation can be found [here](https://binary-patches.readthedocs.io/en/latest/).

## Installation

Up-to-date installation instructions can be found [here](docs/install.md).

